pub struct UserUpdate {
pub handle: ItemDiff<String>,
pub display_name: ItemDiff<String>,
pub add_to_bio: Vec<(String, String)>,
pub rm_from_bio: BTreeSet<String>,
pub services: BTreeSet<SetDiff<String>>,
pub avi_data: ItemDiff<Vec<u8>>,
}Expand description
All the ways a UserData can change, as individual events.
Fields
handle: ItemDiff<String>Set or blank the User’s handle
display_name: ItemDiff<String>Set or blank the User’s display name
add_to_bio: Vec<(String, String)>Add or update a biography line with the given key to the given value.
rm_from_bio: BTreeSet<String>Remove a biography line with the given key, or do nothing if it does not exist.
services: BTreeSet<SetDiff<String>>Add a service with the given name.
avi_data: ItemDiff<Vec<u8>>Set or blank the User’s avatar.